@@ -20,6 +20,7 @@
 import dbus
 import time
 import gobject
+import sys
 
 if getattr(dbus, 'version', (0, 0, 0)) < (0, 80, 0):
     import dbus.glib
@@ -27,22 +28,30 @@ else:
     from dbus.mainloop.glib import DBusGMainLoop
     DBusGMainLoop(set_as_default=True)
 
-bus = dbus.SystemBus()
-proxy_obj = bus.get_object('org.wicd.daemon', '/org/wicd/daemon')
-daemon = dbus.Interface(proxy_obj, 'org.wicd.daemon')
+try:
+    bus = dbus.SystemBus()
+    proxy_obj = bus.get_object('org.wicd.daemon', '/org/wicd/daemon')
+    daemon = dbus.Interface(proxy_obj, 'org.wicd.daemon')
+except Exception, e:
+    print>>sys.stderr, "Exception caught: %s" % str(e)
+    print>>sys.stderr, 'Could not connect to daemon.'
+    sys.exit(1)
 
-def reply_handle():
-    loop.quit()
-def error_handle(e):
+def handler(*args):
     loop.quit()
 
-print daemon.Hello()
-time.sleep(3)
-daemon.SetSuspend(False)
-if not daemon.CheckIfConnecting():
-    print daemon.AutoConnect(True, reply_handler=reply_handle,
-                             error_handler=error_handle)
-    daemon.SetForcedDisconnect(False)
-    
-loop = gobject.MainLoop()
-loop.run()
+def error_handler(*args):
+    print>>sys.stderr, 'Async error autoconnecting.'
+    sys.exit(3)
+
+if __name__ == '__main__':
+    try:
+        time.sleep(3)
+        daemon.SetSuspend(False)
+        if not daemon.CheckIfConnecting():
+            daemon.SetForcedDisconnect(False)
+            daemon.AutoConnect(True, reply_handler=handler, error_handler=handler)
+    except Exception, e:
+        print>>sys.stderr, "Exception caught: %s" % str(e)
+        print>>sys.stderr, 'Error autoconnecting.'
+        sys.exit(2)
