@@ -138,6 +138,9 @@ language["wired_detect"] = _("Wired Link Detection")
 language["route_flush"] = _("Route Table Flushing")
 language["no_global_dns"] = _("Global DNS is not enabled in preferences, so it can't be used for this network")
 language['scripts_need_root'] = _('You must enter your password to configure scripts')
+language['scripts_need_pass'] = _('You must enter your password to configure scripts')
+language['no_sudo_prog'] = _("Could not find a graphical sudo program.  The script editor could not be launched." +
+                             "  You'll have to edit scripts directly your configuration file.")
 
 language['0'] = _('0')
 language['1'] = _('1')
@@ -812,19 +815,17 @@ class WiredNetworkEntry(NetworkEntry):
     def edit_scripts(self, widget=None, event=None):
         """ Launch the script editting dialog. """
         profile = self.combo_profile_names.get_active_text()
-        try:
-            sudo_prog = misc.choose_sudo_prog()
-            msg = "'%s.'" % language['scripts_need_root']
-            if sudo_prog.endswith("gksudo") or sudo_prog.endswith("ktsuss"):
-                msg_flag = "--message"
-            else:
-                msg_flag = "--caption"
-            misc.LaunchAndWait(' '.join([sudo_prog, msg_flag, msg, 
-                                         os.path.join(wpath.lib, "configscript.py"),
-                                         profile, "wired"]))
-        except misc.WicdError:
-            error("Could not find a graphical sudo program." + \
-                  "  Script editor could not be launched.")
+        cmdend = [os.path.join(wpath.lib, "configscript.py"), profile, "wired"]
+        if os.getuid() != 0:
+            cmdbase = misc.get_sudo_cmd(language['scripts_need_pass'])
+            if not cmdbase:
+                error(None, language["no_sudo_prog"]) 
+                return
+            cmdbase.extend(cmdend)
+            misc.LaunchAndWait(cmdbase)
+        else:
+            misc.LaunchAndWait(cmdend)
+
 
     def check_enable(self):
         """ Disable objects if the profile list is empty. """
@@ -1084,19 +1085,17 @@ class WirelessNetworkEntry(NetworkEntry):
 
     def edit_scripts(self, widget=None, event=None):
         """ Launch the script editting dialog. """
-        try:
-            sudo_prog = misc.choose_sudo_prog()
-            msg = "'%s.'" % language['scripts_need_root']
-            if sudo_prog.endswith("gksudo") or sudo_prog.endswith("ktsuss"):
-                msg_flag = "-m"
-            else:
-                msg_flag = "--caption"
-            misc.LaunchAndWait(' '.join([sudo_prog, msg_flag, msg, 
-                                         os.path.join(wpath.lib, "configscript.py"), 
-                                         str(self.networkID), "wireless"]))
-        except misc.WicdError:
-            error(None, "Could not find a graphical sudo program." + \
-                  "  Script editor could no be launched.")
+        cmdend = [os.path.join(wpath.lib, "configscript.py"), 
+                                str(self.networkID), "wireless"]
+        if os.getuid() != 0:
+            cmdbase = misc.get_sudo_cmd(language['scripts_need_pass'])
+            if not cmdbase:
+                error(None, language["no_sudo_prog"]) 
+                return
+            cmdbase.extend(cmdend)
+            misc.LaunchAndWait(cmdbase)
+        else:
+            misc.LaunchAndWait(cmdend)
 
     def update_autoconnect(self, widget=None):
         """ Called when the autoconnect checkbox is toggled. """
@@ -1472,7 +1471,7 @@ class appGui:
             wired.SetAlwaysShowWiredInterface(wiredcheckbox.get_active())
             daemon.SetAutoReconnect(reconnectcheckbox.get_active())
             daemon.SetDebugMode(debugmodecheckbox.get_active())
-            daemon.SetSignalDisplayType(displaytypecheckbox.get_active())
+            daemon.SetSignalDisplayType(int(displaytypecheckbox.get_active()))
             if showlistradiobutton.get_active():
                 wired.SetWiredAutoConnectMethod(2)
             elif lastusedradiobutton.get_active():
