@@ -21,6 +21,7 @@ import os
 import locale
 import gettext
 import sys
+import re
 from subprocess import Popen, STDOUT, PIPE, call
 import commands
 
@@ -49,7 +50,7 @@ ROUTE = 2
 class WicdError(Exception):
     pass
     
-
+__LANG = None
 def Run(cmd, include_stderr=False, return_pipe=False):
     """ Run a command.
 
@@ -66,7 +67,8 @@ def Run(cmd, include_stderr=False, return_pipe=False):
                   one output string from the command.
 
     """
-    if type(cmd) is not list:
+    global __LANG
+    if not isinstance(cmd, list):
         cmd = to_unicode(str(cmd))
         cmd = cmd.split()
     if include_stderr:
@@ -76,24 +78,41 @@ def Run(cmd, include_stderr=False, return_pipe=False):
         err = None
         fds = False
     
+    if not __LANG:
+        __LANG = get_good_lang()
+
     tmpenv = os.environ.copy()
-    tmpenv["LC_ALL"] = "C"
-    tmpenv["LANG"] = "C"
-    f = Popen(cmd, shell=False, stdout=PIPE, stderr=err, close_fds=fds, cwd='/',
-              env=tmpenv)
+    tmpenv["LC_ALL"] = __LANG
+    tmpenv["LANG"] = __LANG
+    try:
+        f = Popen(cmd, shell=False, stdout=PIPE, stderr=err, close_fds=fds,
+                  cwd='/', env=tmpenv)
+    except OSError, e:
+        print "Running command %s failed: %s" % (str(cmd), str(e))
+        return ""
+        
     
     if return_pipe:
         return f.stdout
     else:
         return f.communicate()[0]
     
+def get_good_lang():
+    """ Check if en_US.utf8 is an available locale, if not use C. """
+    output = Popen(["locale", "-a"], shell=False, stdout=PIPE).communicate()[0]
+    if "en_US.utf8" in output:
+        return "en_US.utf8"
+    else:
+        return "C"
+    
 def LaunchAndWait(cmd):
     """ Launches the given program with the given arguments, then blocks.
 
     cmd : A list contained the program name and its arguments.
     
     """
-    call(cmd, shell=True)
+    
+    call(cmd, shell=False)
 
 def IsValidIP(ip):
     """ Make sure an entered IP is valid. """
@@ -316,19 +335,24 @@ def get_gettext():
 
 def to_unicode(x):
     """ Attempts to convert a string to utf-8. """
-    # If this is a unicode string, just encode it and return.
-    if type(x) not in [unicode, str]:
+    # If this is a unicode string, encode it and return
+    if not isinstance(x, basestring):
         return x
-    if type(x) == unicode:
+    if isinstance(x, unicode):
         return x.encode('utf-8')
-    try: # This may never fail, but let's be safe
-        encoding = locale.getpreferredencoding()
-    except:
-        # Just guess utf-8 if it fails.
-        encoding = 'utf-8'
-    ret = x.decode(encoding, 'replace').encode('utf-8')
+    encoding = locale.getpreferredencoding()
+    try:
+        ret = x.decode(encoding).encode('utf-8')
+    except UnicodeError:
+        try:
+            ret = x.decode('utf-8').encode('utf-8')
+        except UnicodeError:
+            try:
+                ret = x.decode('latin-1').encode('utf-8')
+            except UnicodeError:
+                ret = x.decode('utf-8', 'replace').encode('utf-8')
     return ret
-    
+
 def RenameProcess(new_name):
     if sys.platform != 'linux2':
         print 'Unsupported platform'
@@ -361,6 +385,17 @@ def detect_desktop_environment():
     
     return desktop_environment
 
+def get_sudo_cmd(msg):
+    """ Returns a graphical sudo command for generic use. """
+    sudo_prog = choose_sudo_prog()
+    if not sudo_prog: return None
+    if re.search("(ktsuss|gksu|gksudo)$", sudo_prog):
+        msg_flag = "-m"
+    else:
+        msg_flag = "--caption"
+    return [sudo_prog, msg_flag, msg]
+
+
 def choose_sudo_prog():
     desktop_env = detect_desktop_environment()
     env_path = os.environ['PATH'].split(":")
@@ -380,7 +415,7 @@ def choose_sudo_prog():
     raise WicdError("Couldn't find graphical sudo program.")
 
 def find_path(cmd):
-    paths = os.getenv("PATH", default=["/usr/bin", "/usr/local/bin"]).split(':')
+    paths = os.getenv("PATH", default="/usr/bin:/usr/local/bin").split(':')
     for path in paths:
         if os.access(os.path.join(path, cmd), os.F_OK):
             return os.path.join(path, cmd)
