@@ -144,48 +144,49 @@ class ConnectionStatus(object):
         wifi_ip = None
     
         try:
-            if daemon.GetSuspend():
-                print "Suspended."
-                state = misc.SUSPENDED
-                self.update_state(state)
-                return True
+            try:
+                if daemon.GetSuspend():
+                    print "Suspended."
+                    state = misc.SUSPENDED
+                    self.update_state(state)
+                    return True
 
-            # Determine what our current state is.
-            # Are we currently connecting?
-            if daemon.CheckIfConnecting():
-                state = misc.CONNECTING
-                self.update_state(state)
-                return True
+                # Determine what our current state is.
+                # Are we currently connecting?
+                if daemon.CheckIfConnecting():
+                    state = misc.CONNECTING
+                    self.update_state(state)
+                    return True
                 
-            # Check for wired.
-            wired_ip = wired.GetWiredIP()
-            wired_found = self.check_for_wired_connection(wired_ip)
-            if wired_found:
-                self.update_state(misc.WIRED, wired_ip=wired_ip)
-                return True
+                # Check for wired.
+                wired_ip = wired.GetWiredIP()
+                wired_found = self.check_for_wired_connection(wired_ip)
+                if wired_found:
+                    self.update_state(misc.WIRED, wired_ip=wired_ip)
+                    return True
 
-            # Check for wireless
-            wifi_ip = wireless.GetWirelessIP()
-            self.iwconfig = wireless.GetIwconfig()
-            self.signal_changed = False
-            wireless_found = self.check_for_wireless_connection(wifi_ip)
-            if wireless_found:
-                self.update_state(misc.WIRELESS, wifi_ip=wifi_ip)
-                return True
+                # Check for wireless
+                wifi_ip = wireless.GetWirelessIP()
+                self.iwconfig = wireless.GetIwconfig()
+                self.signal_changed = False
+                wireless_found = self.check_for_wireless_connection(wifi_ip)
+                if wireless_found:
+                    self.update_state(misc.WIRELESS, wifi_ip=wifi_ip)
+                    return True
             
-            state = misc.NOT_CONNECTED
-            if self.last_state == misc.WIRELESS:
-                from_wireless = True
-            else:
-                from_wireless = False
-            self.auto_reconnect(from_wireless)
-            self.update_state(state)
-            self.dbus_error_count = 0
-        except dbus.exceptions.DBusException, e:
-            print 'Ignoring DBus Error: ' + str(e)
-            self.dbus_error_count += 1
-            if self.dbus_error_count > 5:
-                raise dbus.exceptions.DBusException(e)
+                state = misc.NOT_CONNECTED
+                if self.last_state == misc.WIRELESS:
+                    from_wireless = True
+                else:
+                    from_wireless = False
+                self.auto_reconnect(from_wireless)
+                self.update_state(state)
+                self.dbus_error_count = 0
+            except dbus.exceptions.DBusException, e:
+                print 'Ignoring DBus Error: ' + str(e)
+                self.dbus_error_count += 1
+                if self.dbus_error_count > 5:
+                    raise dbus.exceptions.DBusException(e)
         finally:
             return True
 
@@ -260,14 +261,15 @@ class ConnectionStatus(object):
     def rescan_networks(self):
         """ Calls a wireless scan. """
         try:
-            if daemon.GetSuspend() or daemon.CheckIfConnecting():
-                return True
-            wireless.Scan()
-        except dbus.exceptions.DBusException:
-            print 'dbus exception while attempting rescan'
+            try:
+                if daemon.GetSuspend() or daemon.CheckIfConnecting():
+                    return True
+                wireless.Scan()
+            except dbus.exceptions.DBusException:
+                print 'dbus exception while attempting rescan'
         finally:
             return True
-        
+
 def reply_handle():
     """ Just a dummy function needed for asynchronous dbus calls. """
     pass
@@ -281,8 +283,7 @@ def main(args):
     """ Starts the connection monitor. 
     
     Starts a ConnectionStatus instance, sets the status to update
-    every two seconds, and sets a wireless scan to be called every
-    two minutes.
+    every four seconds.
     
     """
     monitor = ConnectionStatus()
