@@ -26,13 +26,26 @@ Used for when a laptop enters hibernation/suspension.
 
 import dbus
 import dbus.service
+import sys
+
+try:
+    bus = dbus.SystemBus()
+    proxy_obj = bus.get_object('org.wicd.daemon', '/org/wicd/daemon')
+    daemon = dbus.Interface(proxy_obj, 'org.wicd.daemon')
+except Exception, e:
+    print>>sys.stderr, "Exception caught: %s" % str(e)
+    print>>sys.stderr, 'Could not connect to daemon.'
+    sys.exit(1)
+    
 
-bus = dbus.SystemBus()
-proxy_obj = bus.get_object('org.wicd.daemon', '/org/wicd/daemon')
-daemon = dbus.Interface(proxy_obj, 'org.wicd.daemon')
 
 if __name__ == '__main__':
-    daemon.Disconnect()
-    daemon.SetForcedDisconnect(False)
-    daemon.SetSuspend(True)
-
+    try:
+        daemon.Disconnect()
+        daemon.SetForcedDisconnect(False)
+        daemon.SetSuspend(True)
+    except Exception, e:
+        print>>sys.stderr, "Exception caught: %s" % str(e)
+        print>>sys.stderr, 'Error setting suspend.'
+        sys.exit(2)
+        
