@@ -205,7 +205,7 @@ class ConnectionWizard(dbus.service.Object):
 
         """
         # VERSIONNUMBER
-        version = '1.5.6'
+        version = '1.5.9'
         print 'returned version number', version
         return version
 
@@ -215,7 +215,7 @@ class ConnectionWizard(dbus.service.Object):
         print "setting wired interface %s" % (str(interface))
         self.wired.wired_interface = noneToBlankString(interface)
         self.wifi.wired_interface = noneToBlankString(interface)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings","wired_interface", interface)
         config.write(open(self.app_conf, "w"))
@@ -226,7 +226,7 @@ class ConnectionWizard(dbus.service.Object):
         print "setting wireless interface %s" % (str(interface))
         self.wifi.wireless_interface = noneToBlankString(interface)
         self.wired.wireless_interface = noneToBlankString(interface)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings","wireless_interface", interface)
         configfile = open(self.app_conf, "w")
@@ -237,7 +237,7 @@ class ConnectionWizard(dbus.service.Object):
         """ Sets the wpa driver the wpa_supplicant will use. """
         print "setting wpa driver", str(driver)
         self.wifi.wpa_driver = driver
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings","wpa_driver",driver)
         configfile = open(self.app_conf, "w")
@@ -249,7 +249,7 @@ class ConnectionWizard(dbus.service.Object):
         print 'setting use global dns to', use
         use = misc.to_bool(use)
         print 'setting use global dns to boolean', use
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "use_global_dns", use)
         self.use_global_dns = use
@@ -262,7 +262,7 @@ class ConnectionWizard(dbus.service.Object):
     def SetGlobalDNS(self, dns1=None, dns2=None, dns3=None):
         """ Sets the global dns addresses. """
         print "setting global dns"
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "global_dns_1", misc.noneToString(dns1))
         self.dns1 = dns1
@@ -303,7 +303,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon')
     def SetDebugMode(self, debug):
         """ Sets if debugging mode is on or off. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "debug_mode", debug)
         configfile = open(self.app_conf, "w")
@@ -338,9 +338,9 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon')
     def SetSignalDisplayType(self, value):
         """ Sets the signal display type and writes it the wicd config file. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
-        config.set("Settings", "signal_display_type", value)
+        config.set("Settings", "signal_display_type", int(value))
         configfile = open(self.app_conf, "w")
         config.write(configfile)
         self.signal_display_type = int(value)
@@ -417,7 +417,7 @@ class ConnectionWizard(dbus.service.Object):
 
     def _wireless_autoconnect(self):
         """ Attempts to autoconnect to a wireless network. """
-        print "No wired connection present, attempting to autoconnect" + \
+        print "No wired connection present, attempting to autoconnect " + \
               "to wireless network"
         if self.GetWirelessInterface() is None:
             print 'Autoconnect failed because wireless interface returned None'
@@ -463,7 +463,7 @@ class ConnectionWizard(dbus.service.Object):
 
         """
         print 'setting automatically reconnect when connection drops'
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "auto_reconnect", misc.to_bool(value))
         config.write(open(self.app_conf, "w"))
@@ -585,7 +585,6 @@ class ConnectionWizard(dbus.service.Object):
                    info[3] = internal networkid
         SUSPENDED - info[0] = ""
 
-
         """
         self.connection_state = state
         self.connection_info = info
@@ -614,7 +613,7 @@ class ConnectionWizard(dbus.service.Object):
         self.dhcp_client = int(client)
         self.wifi.dhcp_client = int(client)
         self.wired.dhcp_client = int(client)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "dhcp_client", client)
         config.write(open(self.app_conf, "w"))
@@ -623,12 +622,11 @@ class ConnectionWizard(dbus.service.Object):
     def GetLinkDetectionTool(self):
         return self.link_detect_tool
 
-
     @dbus.service.method('org.wicd.daemon')
     def SetLinkDetectionTool(self, link_tool):
         self.link_detect_tool = int(link_tool)
         self.wired.link_tool = int(link_tool)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "link_detect_tool", link_tool)
         config.write(open(self.app_conf, "w"))
@@ -642,7 +640,7 @@ class ConnectionWizard(dbus.service.Object):
         self.flush_tool = int(flush_tool)
         self.wired.flush_tool = int(flush_tool)
         self.wifi.flush_tool = int(flush_tool)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "flush_tool", flush_tool)
         config.write(open(self.app_conf, "w"))
@@ -672,7 +670,6 @@ class ConnectionWizard(dbus.service.Object):
         """ Emits a signal announcing a scan has started. """
         pass
 
-
     @dbus.service.method('org.wicd.daemon')
     @dbus.service.signal(dbus_interface='org.wicd.daemon', signature='')
     def SendEndScanSignal(self):
@@ -759,6 +756,8 @@ class ConnectionWizard(dbus.service.Object):
             print "Setting script properties through the daemon is not" \
                   + " permitted."
             return False
+        if isinstance(value, basestring):
+            value = misc.to_unicode(value)
         self.LastScan[networkid][prop] = misc.Noneify(value)
     #end function SetProperty
 
@@ -895,7 +894,7 @@ class ConnectionWizard(dbus.service.Object):
         # 1 = default profile
         # 2 = show list
         # 3 = last used profile
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings","wired_connect_mode", int(method))
         config.write(open(self.app_conf, "w"))
@@ -955,7 +954,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.wired')
     def SetAlwaysShowWiredInterface(self, value):
         """ Sets always_show_wired_interface to the given value. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         config.set("Settings", "always_show_wired_interface", 
                    misc.to_bool(value))
@@ -1020,7 +1019,7 @@ class ConnectionWizard(dbus.service.Object):
         """ Creates a wired network profile. """
         profilename = misc.to_unicode(profilename)
         print "Creating wired profile for " + profilename
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         if config.has_section(profilename):
             return False
@@ -1042,7 +1041,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.config')
     def UnsetWiredLastUsed(self):
         """ Finds the previous lastused network, and sets lastused to False. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         profileList = config.sections()
         for profile in profileList:
@@ -1055,7 +1054,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.config')
     def UnsetWiredDefault(self):
         """ Unsets the default option in the current default wired profile. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         profileList = config.sections()
         for profile in profileList:
@@ -1068,7 +1067,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.config')
     def GetDefaultWiredNetwork(self):
         """ Returns the current default wired network. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         profileList = config.sections()
         for profile in profileList:
@@ -1080,7 +1079,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.config')
     def GetLastUsedWiredNetwork(self):
         """ Returns the profile of the last used wired network. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         profileList = config.sections()
         for profile in profileList:
@@ -1094,7 +1093,7 @@ class ConnectionWizard(dbus.service.Object):
         """ Deletes a wired network profile. """
         profilename = misc.to_unicode(profilename)
         print "Deleting wired profile for " + str(profilename)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         if config.has_section(profilename):
             config.remove_section(profilename)
@@ -1112,7 +1111,7 @@ class ConnectionWizard(dbus.service.Object):
         if profilename == "":
             return "500: Bad Profile name"
         profilename = misc.to_unicode(profilename)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         if config.has_section(profilename):
             config.remove_section(profilename)
@@ -1131,7 +1130,7 @@ class ConnectionWizard(dbus.service.Object):
         """ Reads a wired network profile in as the currently active profile """
         profile = {}
         profilename = misc.to_unicode(profilename)
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         if config.has_section(profilename):
             for x in config.options(profilename):
@@ -1147,7 +1146,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.config')
     def GetWiredProfileList(self):
         """ Returns a list of all wired profiles in wired-settings.conf. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wired_conf)
         if config.sections():
             return config.sections()
@@ -1161,7 +1160,7 @@ class ConnectionWizard(dbus.service.Object):
             if not conf.has_option(prof, script):
                 conf.set(prof, script, None)
 
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wireless_conf)
         cur_network = self.LastScan[id]
         bssid_key = cur_network["bssid"]
@@ -1203,7 +1202,7 @@ class ConnectionWizard(dbus.service.Object):
             return
         cur_network = self.LastScan[id]
         essid_key = "essid:" + cur_network["essid"]
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wireless_conf)
 
         if not config.has_section(cur_network["bssid"]):
@@ -1221,7 +1220,7 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.config')
     def RemoveGlobalEssidEntry(self, networkid):
         """ Removes the global entry for the networkid provided. """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wireless_conf)
         cur_network = self.LastScan[networkid]
         essid_key = "essid:" + cur_network["essid"]
@@ -1232,18 +1231,21 @@ class ConnectionWizard(dbus.service.Object):
     @dbus.service.method('org.wicd.daemon.config')
     def ReadWirelessNetworkProfile(self, id):
         """ Reads in wireless profile as the active network """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.wireless_conf)
         cur_network = self.LastScan[id]
         essid_key = "essid:" + cur_network["essid"]
         bssid_key = cur_network["bssid"]
         if self.debug_mode:
             print bssid_key
-        if config.has_section(essid_key)and \
-           misc.stringToNone(config.get(essid_key, 'use_settings_globally')):
+        try:
+            if config.has_section(essid_key)and \
+               misc.stringToNone(config.get(essid_key, 'use_settings_globally')):
                 return self._read_wireless_profile(config, cur_network, 
                                                    essid_key)
-        elif config.has_section(bssid_key):
+        except ConfigParser.NoOptionError:
+            pass
+        if config.has_section(bssid_key):
             return self._read_wireless_profile(config, cur_network, bssid_key)
         else:
             cur_network["has_profile"] = False
@@ -1281,7 +1283,7 @@ class ConnectionWizard(dbus.service.Object):
         else:
             height_str = "pref_height"
             width_str = "pref_width"
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         if config.has_section("Settings"):
             config.set("Settings", width_str, width)
@@ -1311,7 +1313,7 @@ class ConnectionWizard(dbus.service.Object):
 
         width = height = -1        
 
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         if config.has_section("Settings"):
             if config.has_option("Settings", width_str):
@@ -1349,7 +1351,7 @@ class ConnectionWizard(dbus.service.Object):
         This method will return a given option from a given section
 
         """
-        config = ConfigParser.ConfigParser()
+        config = ConfigParser.RawConfigParser()
         config.read(self.app_conf)
         if not config.has_section(section):
             config.add_section(section)
@@ -1422,7 +1424,7 @@ class ConnectionWizard(dbus.service.Object):
         else:
             # Write some defaults maybe?
             print "Configuration file not found, creating, adding defaults..."
-            config = ConfigParser.ConfigParser()
+            config = ConfigParser.RawConfigParser()
             config.read(self.app_conf)
             config.add_section("Settings")
             config.set("Settings", "wireless_interface", "wlan0")
@@ -1508,7 +1510,7 @@ class ConnectionWizard(dbus.service.Object):
 def usage():
     # VERSIONNUMBER
     print """
-wicd 1.5.6
+wicd 1.5.9
 wireless (and wired) connection daemon.
 
 Arguments:
@@ -1649,7 +1651,7 @@ def sigterm_caught(sig, frame):
 
 if __name__ == '__main__':
     if os.getuid() != 0:
-        print ("Root priviledges are required for the daemon to run properly." +
+        print ("Root privileges are required for the daemon to run properly." +
                "  Exiting.")
         sys.exit(1)
     main(sys.argv)
