@@ -65,7 +65,7 @@ auth_pattern        = re.compile('.*wpa_state=(.*?)\n', re.I | re.M  | re.S)
 
 RALINK_DRIVER = 'ralink legacy'
 
-blacklist_strict = punctuation.replace("-", "") + " "
+blacklist_strict = '!"#$%&\'()*+,./:;<=>?@[\\]^`{|}~ '
 blacklist_norm = ";`$!*|><&\\"
 blank_trans = maketrans("", "")
 
@@ -1008,7 +1008,7 @@ class WirelessInterface(Interface):
             cmd.extend(['ap', bssid])
         if self.verbose: print cmd
         misc.Run(cmd)
-        
+    
     def GeneratePSK(self, network):
         """ Generate a PSK using wpa_passphrase. 
 
@@ -1020,9 +1020,10 @@ class WirelessInterface(Interface):
         if not wpa_pass_path: return None
         key_pattern = re.compile('network={.*?\spsk=(.*?)\n}.*',
                                  re.I | re.M  | re.S)
-        cmd = ' '.join([wpa_pass_path, network['essid'], network['key']])
+        cmd = [wpa_pass_path, network['essid'], network['key']]
+        if self.verbose: print cmd
         return misc.RunRegex(key_pattern, misc.Run(cmd))
-
+    
     def Authenticate(self, network):
         """ Authenticate with the specified wireless network.
 
@@ -1034,9 +1035,10 @@ class WirelessInterface(Interface):
         if self.wpa_driver == RALINK_DRIVER:
             self._AuthenticateRalinkLegacy(network)
         else:
-            cmd = ''.join(['wpa_supplicant -B -i ', self.iface, ' -c ',
-                       wpath.networks, network['bssid'].replace(':','').lower(),
-                       ' -D ', self.wpa_driver])
+            cmd = ['wpa_supplicant', '-B', '-i', self.iface, '-c',
+                   os.path.join(wpath.networks, 
+                                network['bssid'].replace(':', '').lower()),
+                   '-D', self.wpa_driver]
             if self.verbose: print cmd
             misc.Run(cmd)
 
@@ -1073,6 +1075,7 @@ class WirelessInterface(Interface):
                 print 'WPA_CLI RESULT IS', result
 
             if not result:
+                print "Failed to find status in wpa_cli result %s" % str(output)
                 return False
             if result == "COMPLETED":
                 return True
